% -*- coding: utf-8; -*-
%
% ------------------------------------------------------------
% Copyright 2015-2023 by Paul Gaborit
%
% This file may be distributed and/or modified
%
% 1. under the LaTeX Project Public License and/or
% 2. under the GNU Public License.
%
% See the file mines-albi-these/LICENSE for more details.
%------------------------------------------------------------
\NeedsTeXFormat{LaTeX2e}
\def\mat@version{v0.9.8}
\def\mat@date{2024/04/30}
\ProvidesClass{mines-albi-these}[\mat@date\space\mat@version\space Mines Albi Thesis class]

% Pour définir des commandes facilement
%\RequirePackage[log-declarations=false]{xparse}
\RequirePackage{xparse}

% Pour patcher des macros LaTeX (en conservant la définition initiale)
\RequirePackage{letltxmacro}

% ------------------------------------------------------------
% pour le debug
%------------------------------------------------------------
\NewDocumentCommand\matypemeaning{m}{% #1 est le nom d'une macro (avec le \)
  \typeout{+++ \string#1:\meaning#1}%
}
%\matypemeaning{\tableofcontents}

% Pour les warnings et les erreurs
\NewDocumentCommand\mat@error{m m}{\ClassError{mines-albi-these}{#1}{#2}}
\NewDocumentCommand\mat@warning{m}{\ClassWarning{mines-albi-these}{#1}}

% Pour tester si on utilise luatex
\usepackage{ifluatex}

%------------------------------------------------------------
% les options
%------------------------------------------------------------
% pour gérer les options
\RequirePackage{etoolbox}
\RequirePackage{pgfopts}
\RequirePackage{pgffor}

% l'espace de noms de notre classe
\NewExpandableDocumentCommand\mat@keys@prefix{}{/mat}

% pour utiliser (ou définir) des clés dans notre espace de nom
% \NewDocumentCommand\mat@keys{m}{\pgfqkeys{\mat@keys@prefix}{#1}}

% la même commande... mais utilisable par l'auteur
\NewDocumentCommand\matkeys{m}{\pgfqkeys{\mat@keys@prefix}{#1}}

% choix des langues
\matkeys{
  languages/.store in=\mat@languages,
  main-language/.store in=\mat@mainlanguage,
  % initial values
  languages={american,french},
  main-language=french,
}


% famille de polices
\def\mat@fix@lmodern{%
  % see https://tex.stackexchange.com/a/137143/14500
  % and https://tex.stackexchange.com/a/261188/14500
  \DeclareFontFamily{OMX}{lmex}{}%
  \DeclareFontShape{OMX}{lmex}{m}{n}{%
    <-> lmex10
  }{}%
}
\matkeys{
  font-family/.is choice,
  % all choices
  font-family/lmodern/.style={font-family@apply/.code={
      \RequirePackage{lmodern}
      \AtBeginDocument{\mat@fix@lmodern}
    }},
  font-family/kpfonts/.style={font-family@apply/.code={
      \RequirePackage{kpfonts}
    }},
  font-family/mathptmx/.style={font-family@apply/.code={
      \RequirePackage{mathptmx}
    }},
  font-family/fourier/.style={font-family@apply/.code={
      \RequirePackage{fourier}
    }},
  font-family/source/.style={font-family@apply/.code={
      \RequirePackage{lmodern}
      \AtBeginDocument{\mat@fix@lmodern}
      \RequirePackage[ttdefault]{sourcecodepro}
      \RequirePackage[sfdefault]{sourcesanspro}
      \RequirePackage[default]{sourceserifpro}
      % \RequirePackage[ttdefault,semibold]{sourcecodepro}
      % \RequirePackage[sfdefault,semibold]{sourcesanspro}
      % \RequirePackage[default,semibold]{sourceserifpro}
    }},
  font-family/newtx/.style={font-family@apply/.code={
      \RequirePackage{newtxtext}
      \RequirePackage{newtxmath}
    }},
  font-family/newpx/.style={font-family@apply/.code={
      \RequirePackage{newpxtext}
      \RequirePackage{newpxmath}
    }},
  % initial values
  font-family=lmodern,
}

% la famille de polices pour les titres
\matkeys{
  title-font-family/.is choice,
  title-font-family/serif/.code={\def\mat@title@font@family{\rmfamily}},
  title-font-family/sans-serif/.code={\def\mat@title@font@family{\sffamily}},
  % initial values
  title-font-family=sans-serif,
}

% la liste des styles à charger
\matkeys{
  load-style/.code={
    \def\temp{\mat@style@load{#1}}
    \ifdef{\mat@stylestoload}{
      \edef\mat@stylestoload{\expandonce\mat@stylestoload \expandonce\temp}
    }{
      \edef\mat@stylestoload{\expandonce\temp}
    }
  },
  load-styles/.style={load-style/.list={#1}},
}

% taille de la police
\matkeys{
  font-size/.is choice,
  font-size/10pt/.code={\def\mat@fontsize{10pt}},
  font-size/11pt/.code={\def\mat@fontsize{11pt}},
  font-size/12pt/.code={\def\mat@fontsize{12pt}},
  fontsize/.style={font-size=#1},  % compatiblité ancienne version
  % initial values
  font-size=12pt,
}

% l'espacement entre les lignes
\matkeys{
  setspace/.is choice,
  setspace/single/.code={\def\mat@setspace{single}},
  setspace/onehalf/.code={\def\mat@setspace{onehalf}},
  setspace/double/.code={\def\mat@setspace{double}},
  % initial values
  setspace=single,
}

% le style de paragraphes
\matkeys{
  parskip/.is choice,
  parskip/no-skip/.style={
    parskip@apply/.code={
      \setlength{\parskip}{0\baselineskip plus 5pt}
      \setlength{\parindent}{2em}
      \setlength{\parfillskip}{10\p@ \@plus 1fil}
    },
  },
  parskip/one-line/.style={
    parskip@apply/.code={
      \setlength{\parskip}{.5\baselineskip plus .3\baselineskip minus .2\baselineskip}
      \setlength{\parindent}{0\p@}
      \setlength{\parfillskip}{0\p@ \@plus 1fil}
    },
  },
  % initial value
  parskip=one-line,
}

% niveau de numérotation, tables des matières, table des matières locales, bookmarks (PDF)
\matkeys{
  % niveau de numérotation global
  numbering-depth/.is choice,
  numbering-depth/part/.code={\def\mat@secnumdepth{-1}},
  numbering-depth/chapter/.code={\def\mat@secnumdepth{0}},
  numbering-depth/section/.code={\def\mat@secnumdepth{1}},
  numbering-depth/subsection/.code={\def\mat@secnumdepth{2}},
  numbering-depth/subsubsection/.code={\def\mat@secnumdepth{3}},
  numbering-depth/paragraph/.code={\def\mat@secnumdepth{4}},
  % type de numération
  numbering-type/.is choice,
  numbering-type/1.2.3/.code={\def\mat@sectnumtype{1.2.3}},
  numbering-type/1.2.3./.code={\def\mat@sectnumtype{1.2.3.}},
  numbering-type/1.2.a/.code={\def\mat@sectnumtype{1.2.a}},
  numbering-type/1.2.a./.code={\def\mat@sectnumtype{1.2.a.}},
  % profondeur de la table des matières
  toc-depth/.is choice,
  toc-depth/part/.code={\def\mat@tocdepth{-1}},
  toc-depth/chapter/.code={\def\mat@tocdepth{0}},
  toc-depth/section/.code={\def\mat@tocdepth{1}},
  toc-depth/subsection/.code={\def\mat@tocdepth{2}},
  toc-depth/subsubsection/.code={\def\mat@tocdepth{3}},
  toc-depth/paragraph/.code={\def\mat@tocdepth{4}},
  % profondeur des tables des matières locales
  local-toc-depth/.is choice,
  local-toc-depth/chapter/.code={\def\mat@localtocdepth{0}},
  local-toc-depth/section/.code={\def\mat@localtocdepth{1}},
  local-toc-depth/subsection/.code={\def\mat@localtocdepth{2}},
  local-toc-depth/subsubsection/.code={\def\mat@localtocdepth{3}},
  local-toc-depth/paragraph/.code={\def\mat@localtocdepth{4}},
  %
  localtoc-depth/.style={local-toc-depth=#1}, % compatiblité ancienne version
  mini-toc-depth/.style={local-toc-depth=#1}, % compatiblité ancienne version
  minitoc-depth/.style={local-toc-depth=#1}, % compatiblité ancienne version
  % profondeur d'ouverture des bookmarks
  bookmarks-open-level/.is choice,
  bookmarks-open-level/part/.code={\def\mat@bookmarksopenlevel{-1}},
  bookmarks-open-level/chapter/.code={\def\mat@bookmarksopenlevel{0}},
  bookmarks-open-level/section/.code={\def\mat@bookmarksopenlevel{1}},
  bookmarks-open-level/subsection/.code={\def\mat@bookmarksopenlevel{2}},
  bookmarks-open-level/subsubsection/.code={\def\mat@bookmarksopenlevel{3}},
  bookmarks-open-level/paragraph/.code={\def\mat@bookmarksopenlevel{4}},
  % bookmarks numérotés (ou non)
  bookmarks-numbered/.is choice,
  bookmarks-numbered/true/.code={\def\mat@bookmarksnumbered{true}},
  bookmarks-numbered/false/.code={\def\mat@bookmarksnumbered{false}},
  %
  % initial values
  %
  numbering-depth=subsection,
  numbering-type=1.2.3,
  toc-depth=subsection,
  local-toc-depth=subsection,
  bookmarks-open-level=chapter,
  bookmarks-numbered=true,
}

% les entêtes et pied-de-page
\matkeys{
  header-style/.is choice,
  header-style/part-chapter/.code={\def\mat@headerstyle{part-chapter}},
  header-style/chapter-section/.code={\def\mat@headerstyle{chapter-section}},
  header-style/nohead/.code={\def\mat@headerstyle{nohead}},
}

% les couleurs pour les différents liens
\newbool{mat@gray@colors}
\matkeys{
  %
  link-color/.store in=\mat@color@link,
  url-color/.store in=\mat@color@url,
  citation-color/.store in=\mat@color@citation,
  gray-colors/.is if=mat@gray@colors,
  % initial values
  link-color=blue!50!black,
  url-color=blue,
  citation-color=red!75!black,
  gray-colors=false,
}

% divers réglages PDF
%\newif\ifmat@compressedpdf
\newbool{mat@compressedpdf}
\newbool{mat@pdfa}
\matkeys{
  pdf-compress-level/.store in=\mat@pdfcompresslevel,
  compressed-pdf/.is if=mat@compressedpdf,
  pdfa/.is if=mat@pdfa,
  % initial values
  pdfa=false,
  compressed-pdf=true,
  pdf-compress-level=9,
}


% le mode draft (pour voir les "overfull boxes")
\newbool{mat@showoverfull}
\matkeys{
  show-overfull/.is if=mat@showoverfull,
  % initial value
  show-overfull=false,
}

\AtBeginDocument{
  \setlength\overfullrule{\ifbool{mat@showoverfull}{5pt}{0pt}}
}


% pour la bibliographie
\NewDocumentCommand\mat@load@biblio@style{m m}{% style name, file name
  \usepackage{#2}%
  \matkeys{bibliography-style=#1}%
}
\matkeys{
  bibliography/.store in=\mat@bibliography@options,
  bibliography/biblatex options/.store in=\mat@biblatex@options,
  bibliography/biblatex hook/.code={},
  % some styles
  bibliography-style/.is choice,
  bibliography-style/.unknown/.code={%
    \edef\mat@bibliostylename{\pgfkeyscurrentname}
    \edef\mat@bibliostylefilename{mines-albi-these-bibliography-style-\mat@bibliostylename}%
    \IfFileExists{\mat@bibliostylefilename.sty}{\mat@load@biblio@style{\mat@bibliostylename}{\mat@bibliostylefilename}%
    }{%
      \mat@error
      {Unknown bibliography style: '\mat@bibliostylename' (no file '\mat@bibliostylefilename')}
      {Choose another style}%
    }%
  },
  % apply pg style (default)
  bibliography-style=pg,
}

% pour les options de classe inconnues
\matkeys{
  % .unknown/.code={%
  %   \mat@warning{Unknown class option '\pgfkeyscurrentname'}%
  % },
}

% traitement des options
% \typeout{*** ProcessPgfOptions}
\ProcessPgfOptions{\mat@keys@prefix}

% nettoyage des options
%
\let\mat@classoptionslist\@classoptionslist
\def\@classoptionslist{}
\def\mat@sepkeyval#1=#2\nil{%
  \def\mat@opt{#1}%
  \def\mat@val{#2}%
  %\typeout{*** class option: \mat@opt => \mat@val}%
  \ifdefstring{\mat@opt}{languages}{}{% else
    \ifdefstring{\@classoptionslist}{}{
      \xdef\@classoptionslist{\expandonce\mat@opt=\expandonce\mat@val}%
    }{
      \xdef\@classoptionslist{\expandonce\@classoptionslist,\expandonce\mat@opt=\expandonce\mat@val}%
    }
  }%
}
\foreach \opt in \mat@classoptionslist {
  \ifdefempty{\opt}{}{\expandafter\mat@sepkeyval\opt\nil}
}
%\typeout{@classoptionslist: \@classoptionslist}
%\let\@classoptionslist\relax

%------------------------------------------------------------
% mise en place des réglages
%------------------------------------------------------------

% Pour gérer l'inclusion des formats graphiques
\usepackage[final]{graphicx} 

% PDF 1.5 ou 1.4, compression et PDF/A
%\usepackage{luatex85}
\ifluatex
\ifbool{mat@pdfa}{
  \pdfvariable minorversion=4
}{
  \pdfvariable minorversion=5
}
\else
\ifbool{mat@pdfa}{
  \pdfminorversion=4
}{
  \pdfminorversion=5
}
\fi

\ifbool{mat@compressedpdf}{
  \ifbool{mat@pdfa}{
    \mat@warning{compressed PDF and PDF/A are incompatible: keeping PDF/A}
    \matkeys{pdf-compress-level=0}
  }{
    \matkeys{pdf-compress-level=9}
  }
}{
  \matkeys{pdf-compress-level=0}
}
\ifluatex
\pdfvariable compresslevel=\mat@pdfcompresslevel
\pdfvariable objcompresslevel=\mat@pdfcompresslevel
\else
\pdfcompresslevel=\mat@pdfcompresslevel
\pdfobjcompresslevel=\mat@pdfcompresslevel
\fi

% 'book' est la classe de base
\PassOptionsToClass{%
  \mat@fontsize,a4paper,fleqn,twoside,openright,final,\mat@mainlanguage%
}{book}
\LoadClass{book}

% pour gérer les marges et la taille du papier
\ifdefstring{\mat@fontsize}{10pt}{
  \def\mat@vmargin{3.5cm}
  \def\mat@hmargin{3.5cm}
  \def\mat@marginparwidth{2.5cm}
}{
  \ifdefstring{\mat@fontsize}{11pt}{
    \def\mat@vmargin{3.25cm}
    \def\mat@hmargin{3.25cm}
    \def\mat@marginparwidth{2.25cm}
  }{
    \def\mat@vmargin{3cm}
    \def\mat@hmargin{3cm}
    \def\mat@marginparwidth{2cm}
  }
}
\PassOptionsToPackage{vmargin=\mat@vmargin,hmargin=\mat@hmargin,marginparsep=5mm,marginparwidth=\mat@marginparwidth}{geometry}
\RequirePackage[a4paper,footskip=4em,headsep=2em,twoside]{geometry}

% \if@twoside
% \typeout{===> two side}
% \else
% \typeout{===> one side}
% \fi

% l'espacement entre les lignes
\RequirePackage{setspace}
\ifdefstring{\mat@setspace}{single}{
  % espacement normal: rien à faire
  \singlespacing
}{
  % choix entre 1,5 et 2
  \ifdefstring{\mat@setspace}{onehalf}{
    \onehalfspacing
  }{
    \doublespacing
  }
}


% Pour pouvoir changer la présentation des titres, des entêtes et des pieds-de-page
\RequirePackage[pagestyles,notocpart*,explicit]{titlesec}

% patch titleps depuis LaTeX 2019-10-01. Voir <https://tex.stackexchange.com/a/511870/14500>
%\def\ttl@mb@mark{\csname markboth \endcsname} % patch

% le type de numérotation
\matkeys{
  %
  apply numbering type/.is choice,
  apply numbering type/1.2.3/.code={
    \renewcommand\thechapter{\arabic{chapter}}
    \renewcommand\thesection{\thechapter.\arabic{section}}
    \renewcommand\thesubsection{\thesection.\arabic{subsection}}
  },
  apply numbering type/1.2.3./.code={
    \renewcommand\thechapter{\arabic{chapter}.}
    \renewcommand\thesection{\thechapter\arabic{section}.}
    \renewcommand\thesubsection{\thesection\arabic{subsection}.}
  },
  apply numbering type/1.2.a/.code={
    \renewcommand\thechapter{\arabic{chapter}}
    \renewcommand\thesection{\thechapter.\arabic{section}}
    \renewcommand\thesubsection{\thesection.\alph{subsection}}
  },
  apply numbering type/1.2.a./.code={
    \renewcommand\thechapter{\arabic{chapter}.}
    \renewcommand\thesection{\thechapter\arabic{section}.}
    \renewcommand\thesubsection{\thesection\alph{subsection}.}
  },
  % apply chosen type
  apply numbering type=\mat@sectnumtype,
}

%%%%%
% Pour gérer les tables des matières

\RequirePackage{etoc}
% pas de tables des matières vides
\etocchecksemptiness
% on utilise le niveau -2 pour les grandes divisions (frontmatter,
% mainmatter et backmatter)
\def\Etoc@minf{-\thr@@}

% profondeur des tables des matières générales
\setcounter{tocdepth}{5}

% Une fin de partie change la profondeur des chapitres qui suivent
\NewDocumentCommand\endofpart{}{%
  \bookmarksetup{startatroot}%
  \etoctoccontentsline{EndOfPart}{main}%
  \addtocontents{toc}{\protect\unset@mat@inpart}%
  \partmark{}%
  \cleardoublepage%
}

% pour faire des boxs de même taille
\RequirePackage{eqparbox}

%------------------------------------------------------------
% pour les liens hypertext (internes et externes)
%------------------------------------------------------------

\RequirePackage[hyphens]{url}
\RequirePackage{xr-hyper}

% pour utiliser varioref, il faut changer \ref en \vref (page suivante, etc)

% \mat@keys{
%   babel to varioref languages/.is family,
%   babel to varioref languages/.cd,
%   empty varioref languages list/.code={\def\mat@varioref@languages{\mat@mainlanguage}},
%   english/.code=
% }
% \foreach\mat@language in {\mat@languages}{
%   \edef\mat@varioref@language{\mat@language}
%   \ifdefstring{\mat@varioref@language}{british}{\def\mat@varioref@language{british}}
%   \ifdefstring{\mat@varioref@language}{canadian}{\def\mat@varioref@language{british}}
% }
\RequirePackage[\mat@mainlanguage]{varioref}


\ifbool{mat@pdfa}{\PassOptionsToPackage{pdfa}{hyperref}}{}
\RequirePackage[final]{hyperref}
% \RequirePackage{refcount}
\hypersetup{
  unicode=true,
  pdfprintscaling=None,  
  breaklinks=true,
  %
  colorlinks=true,
  linkcolor=\mat@color@link,
  urlcolor=\mat@color@url,
  citecolor=\mat@color@citation,
  filecolor=\mat@color@url,
  %
  linktoc=all,
  bookmarksopen,%
  bookmarksopenlevel=\mat@bookmarksopenlevel,%
  bookmarksnumbered=\mat@bookmarksnumbered,%
  pdfpagelayout=TwoPageRight,
}

% Pour gérer le contenu et le développement par défaut des bookmarks PDF
\RequirePackage[open]{bookmark}

%---------------------------------------
% Pour gérer l'inclusion des formats graphiques
\RequirePackage[final]{graphicx} 
% pour accepter les espaces, les multi-points dans les noms de
% fichiers... même si ce n'est pas bien !
\RequirePackage[extendedchars]{grffile}

%=================================================
% FONT - LANGUE - ENCODAGE ...
%-----------------------------
% Encodage des fichiers (en entrée)
\RequirePackage[utf8]{luainputenc}

% Un petit plus pour la conversion PDF vers texte
\usepackage{cmap}
% Encodage des fonts (en sortie dans le pdf par exemple)
\RequirePackage[T1]{fontenc}

% Famille de fonts :
\matkeys{font-family@apply}

% pour ajouter l'euro € par exemple, mais aussi d'autres symboles
\RequirePackage{textcomp}

%=================================================

%---------------------------------------
% Pour régler l'indentation des paragraphes et l'espacement entre les
% paragraphes
\matkeys{parskip@apply}

%---------------------------------------
%permet de ne pas obliger le texte à aller jusqu'au bas de la page :
%\raggedbottom


% Si on veut éliminer les espaces générés derrière une commande :
\RequirePackage{xspace} 

% Pour pivoter une figure ou un table... en conservant l'entête et le
% pied de page d'origine
\RequirePackage{lscape}

% Pour définir ses propres couleurs
\ifbool{mat@gray@colors}{
  \RequirePackage[gray,svgnames,table]{xcolor}
  \PassOptionsToPackage{gray}{mines-albi-these-frontpage}
}{
  \RequirePackage[svgnames,table]{xcolor}
}


% bleu, couleur du savoir !
\definecolor{mines-albi-bleu}{HTML}{4376AC} 
%gris chrome, couleur de l'innovation technologique !
\definecolor{mines-albi-gris}{HTML}{E3E6EA} 
%orange, couleur de l'architecture d'Albi, de l'ancrage dans l'environnement !
\definecolor{mines-albi-orange}{HTML}{FF8C00} 

%\RequirePackage{float}

%---------------------------------------
% Pour bien séparer les flottants (float) du reste du texte
% \setlength{\floatsep}{24pt}
% \setlength{\textfloatsep}{36pt}

%---------------------------------------
% réglage au micropoil des ligatures et autres pour du pdf
\RequirePackage[final]{microtype} %expansion...
%=================================================

%----- Nécessaire pour la Couverture INPT
% Pour faire de jolis graphiques
%\RequirePackage{tikz}
% \usetikzlibrary{positioning,shadows,backgrounds,shapes.geometric}
%-----



%=================================================
% TABLEAUX
%-----------------
% J'aime bien faire des tables et tableaux nickels,
% pour ça on a besoin de : 
\RequirePackage{tabu,longtable} % pour définir des tabu et longtabu
\RequirePackage{booktabs}



%=================================================
% MATH
\RequirePackage{mathtools,amsmath,amsfonts,amssymb}

%----------
% NUMEROTATION DES ÉQUATIONS :
%\renewcommand{\theequation}{\thesection.\arabic{equation}}
% permet de réinitialiser le compteur à chaque nouvelle section :
% \numberwithin{equation}{section} 

%=================================================
%  LANGUE 
%  ----------
% \typeout{*** languages: \mat@languages, main language: \mat@mainlanguage}
\RequirePackage[\mat@languages,\mat@mainlanguage,main=\mat@mainlanguage]{babel}
\ifdefstring{\mat@mainlanguage}{french}{
  \frenchbsetup{PartNameFull=false}
}{}


% =================================================
% BIBLIOGRAPHIE
% -------------
\RequirePackage{mines-albi-these-bibliography}


% =================================================
% CAPTIONS
% --------
\RequirePackage{caption}
\RequirePackage{subcaption}
\captionsetup{margin=10pt,labelfont=bf}

% =================================================
% SI UNITS
% Permet de gérer avec soin les unités et les nombres
% pour charger les traductions de toutes les langues (en particulier pour siunitx)
\RequirePackage[\mat@languages,\mat@mainlanguage]{translator}
% pour choisir le 'locale' principal de siunitx en fonction de la langue
\matkeys{
  locale-siunitx/.is family,
  locale-siunitx,
  %
  link babel and siunitx/.code 2 args={%
    \expandafter\addto\csname extras#1\endcsname{\sisetup{locale=#2}}
    \def\mat@siunitx@locale{locale=#2}%
  },
  % 
  american/.style={link babel and siunitx={american}{UK}},
  british/.style={link babel and siunitx={british}{UK}},
  english/.style={link babel and siunitx={english}{UK}},
  %
  francais/.style={link babel and siunitx={french}{FR}},
  french/.style={link babel and siunitx={french}{FR}},
  canadien/.style={link babel and siunitx={canadien}{FR}},
  acadian/.style={link babel and siunitx={acadian}{FR}},
  %
  german/.style={link babel and siunitx={german}{DE}},
  ngerman/.style={link babel and siunitx={ngerman}{DE}},
  austrian/.style={link babel and siunitx={austrian}{DE}},
  naustrian/.style={link babel and siunitx={naustrian}{DE}},
  % 
  spanish/.code={%
    \mat@warning{The siunitx package does not provide locale for language
      '\pgfkeyscurrentname' (using FR locale)}%
    \def\mat@siunitx@locale{locale=FR}%
  },
  % %
  portuguese/.code={%
    \mat@warning{The siunitx package does not provide locale for language
      '\pgfkeyscurrentname' (using FR locale)}%
    \def\mat@siunitx@locale{locale=FR}%
  },
  %
  apply language/.style={#1},
  apply language/.list/.expanded=\mat@languages,
  apply language=\mat@mainlanguage,
}

\RequirePackage[%
%locale=FR,                                % permet d'imposer des règles
%de typo de numérotation française
\mat@siunitx@locale,
% inter-unit-separator={}\cdot{}, % permet de mettre des \cdot entre les unités
% load-configurations=abbreviations, % charge les abbréviations classiques du système SI
group-digits=integer, % le regroupement par 3 chiffres mais...
group-minimum-digits=5, % ... si au moins 5 chiffres
detect-all, % utilise la police et sa variante courante
]{siunitx}
% contournement d'un bug... conflit entre tabu et siunitx
%\ExplSyntaxOn
%\cs_new_eq:NN \siunitx_table_collect_begin:Nn \__siunitx_table_collect_begin:Nn
%\ExplSyntaxOff

%=================================================

% pour éviter les veuves et les orphelines
\RequirePackage[all]{nowidow}

% À essayer (pour voir si on obtient de meilleurs résultats que le
% packae prédécedent)
%\RequirePackage[avoid-all,check=warning]{widows-and-orphans}

% Pour savoir dans quel fichier on est...
\RequirePackage{currfile}

\def\mat@style@load#1{
  \def\stylefilename{mines-albi-these-style-#1}
  \IfFileExists{\stylefilename.sty}{\RequirePackage{\stylefilename}}
  {\mat@error{Can't find style file '\stylefilename'}{Choose a pre-defined style...}}
  % initialisation du style
  \matkeys{style/#1/init,style/#1}
  % \@for\mat@temp:=part,chapter,section,subsection,subsubsection,paragraph,subparagraph\do{
  %   \typeout{forcing use of style #1 \mat@temp}
  %   \matkeys{sect/style/#1/\mat@temp/.try,sect/style/#1/\mat@temp*/.try}
  % }
  \def\mat@global@style{#1}
}

\def\mat@apply@style#1{%
  % \typeout{==> style: #1}
  \matkeys{style/#1}%
}

\ifdef{\mat@stylestoload}{
  \ifdefempty{\mat@stylestoload}{
    %\typeout{*** empty style}
    \mat@style@load{jjl}%
  }{
    %\typeout{*** list of styles: \meaning\mat@stylestoload}
    \mat@stylestoload%
  }
}{
  %\typeout{*** empty style}
  \mat@style@load{jjl}
}

\RequirePackage{mines-albi-these-style}

\RequirePackage{mines-albi-these-glossaries}

\newenvironment{enlargedcontent}[1]{%
  \begin{list}{}{%
      \pgfmathsetmacro\mat@enlarge{-1*#1}%
      \setlength{\topsep}{0pt}%
      \setlength{\leftmargin}{\mat@enlarge pt}%
      \setlength{\rightmargin}{\mat@enlarge pt}%
      \setlength{\listparindent}{0cm}%
      \setlength{\itemindent}{0cm}%
      \setlength{\parsep}{\parskip}}%
  \item[]%
}{%
  \end{list}%
}


\RequirePackage{tikzpagenodes}
\usetikzlibrary{fit}

\NewDocumentCommand\showlayout{}{%
  \begin{tikzpicture}[remember picture,overlay]
    \tikzset{fit to/.style={fit=(##1),inner sep=-.5\pgflinewidth}}
    \node[fit to=current page text area,draw=red!50!black]{};
    \node[fit to=current page marginpar area,draw=orange]{};
    \node[fit to=current page header area,draw=cyan!50!blue]{};
    \node[fit to=current page footer area,draw=green!50!black]{};
  \end{tikzpicture}%
}

\LetLtxMacro\mat@titleorig\title
\RenewDocumentCommand\title{om}{%
  \def\mat@Title{#2}%
  \IfNoValueTF{#1}{\hypersetup{pdftitle={#2}}}{\hypersetup{pdftitle={#1}}}
  \mat@titleorig{#2}
}

\LetLtxMacro\mat@dateorig\date
\RenewDocumentCommand\date{m}{
  \def\mat@Date{#1}%
  \mat@dateorig{#1}%
}

\LetLtxMacro\mat@authororig\author
\RenewDocumentCommand\author{om}{%
  \def\mat@author{#2}%
  \IfNoValueTF{#1}{\hypersetup{pdfauthor={#2}}}{\hypersetup{pdfauthor={#1}}}%
  \mat@authororig{#2}%
}

% Pour fabriquer le résumé (en deux langues)

\NewDocumentCommand\abstract{O{1} mmm+m mmm+m}{%
  % linewidth, language1, abstractname, title, abstract, language2, abstractname, title, abstract,
  \pgfmathsetmacro\mat@abstact@vmargin{(\mat@vmargin-5mm)*#1 + 5mm}%
  \pgfmathsetmacro\mat@abstact@hmargin{(\mat@hmargin-5mm)*#1 + 5mm}%
  \pgfmathsetmacro\mat@abstact@marginparwidth{\mat@marginparwidth*#1}%
  \newgeometry{%
    vmargin=\mat@abstact@vmargin pt,%
    hmargin=\mat@abstact@hmargin pt,%
    marginparwidth=\mat@abstact@marginparwidth pt,%
    nohead,nofoot%
  }%
  \thispagestyle{empty}%
  \bgroup
  \newcommand\keywords[2]{{\footnotesize\textsc{##1} ##2\par}}
  \null
  \vfill
  \begin{otherlanguage*}{#2}
    {\centering\textsc{\textbf{#3}}\par}
    \textbf{#4}\par
    #5
  \end{otherlanguage*}
  \vfill
  %
  {\centering \rule{0.5\linewidth}{0.1mm}\par}
  % 
  \vfill
  \begin{otherlanguage*}{#6}
    {\centering\textsc{\textbf{#7}}\par}
    \textbf{#8}\par
    #9
  \end{otherlanguage*}
  \vfill
  \null
  \egroup
  \restoregeometry
}

